@@ -41,6 +41,12 @@ FAILEDOPERATION_DELETEKEYPAIRFAILED = 'FailedOperation.DeleteKeyPairFailed'
 # 查询镜像失败，请稍后再试。
 FAILEDOPERATION_DESCRIBEBLUEPRINTSFAILED = 'FailedOperation.DescribeBlueprintsFailed'
 
+# 查询套餐折扣失败
+FAILEDOPERATION_DESCRIBEBUNDLEDISCOUNTFAILED = 'FailedOperation.DescribeBundleDiscountFailed'
+
+# 查询套餐失败
+FAILEDOPERATION_DESCRIBEBUNDLESFAILED = 'FailedOperation.DescribeBundlesFailed'
+
 # 查询实例状态错误。
 FAILEDOPERATION_DESCRIBEINSTANCESTATUS = 'FailedOperation.DescribeInstanceStatus'
 
@@ -59,6 +65,12 @@ FAILEDOPERATION_DESCRIBERESOURCESRETURNABLEERROR = 'FailedOperation.DescribeReso
 # 销毁资源失败，请稍后重新操作。
 FAILEDOPERATION_DESTROYRESOURCESFAILED = 'FailedOperation.DestroyResourcesFailed'
 
+# 容器列表过长。
+FAILEDOPERATION_DOCKERCONTAINERSLISTTOOLARGE = 'FailedOperation.DockerContainersListTooLarge'
+
+# 指定Docker环境操作失败, 请检查Docker环境。
+FAILEDOPERATION_DOCKEROPERATIONFAILED = 'FailedOperation.DockerOperationFailed'
+
 # 对防火墙规则的操作失败。
 FAILEDOPERATION_FIREWALLRULESOPERATIONFAILED = 'FailedOperation.FirewallRulesOperationFailed'
 
@@ -68,6 +80,9 @@ FAILEDOPERATION_IMPORTKEYPAIRFAILED = 'FailedOperation.ImportKeyPairFailed'
 # 对实例的操作失败。
 FAILEDOPERATION_INSTANCEOPERATIONFAILED = 'FailedOperation.InstanceOperationFailed'
 
+# 账户余额不足, 请及时充值。
+FAILEDOPERATION_INSUFFICIENTBALANCE = 'FailedOperation.InsufficientBalance'
+
 # 命令无法找到。
 FAILEDOPERATION_INVALIDCOMMANDNOTFOUND = 'FailedOperation.InvalidCommandNotFound'
 
@@ -80,16 +95,28 @@ FAILEDOPERATION_MODIFYINSTANCESBUNDLEFAILED = 'FailedOperation.ModifyInstancesBu
 # 变更资源属性失败，请稍后重新操作。
 FAILEDOPERATION_MODIFYRESOURCESATTRIBUTEFAILED = 'FailedOperation.ModifyResourcesAttributeFailed'
 
+# 修改资源自动续费失败
+FAILEDOPERATION_MODIFYRESOURCESRENEWFLAGFAILED = 'FailedOperation.ModifyResourcesRenewFlagFailed'
+
 # 续费资源失败。
 FAILEDOPERATION_RENEWRESOURCESFAILED = 'FailedOperation.RenewResourcesFailed'
 
 # 请求错误。
 FAILEDOPERATION_REQUESTERROR = 'FailedOperation.RequestError'
 
+# 扩容云硬盘失败，请稍后重新操作。
+FAILEDOPERATION_RESIZEDISKSFAILED = 'FailedOperation.ResizeDisksFailed'
+
+# 跨账号共享镜像失败，请稍后重试。
+FAILEDOPERATION_SHAREBLUEPRINTACROSSACCOUNTFAILED = 'FailedOperation.ShareBlueprintAcrossAccountFailed'
+
 # 快照操作失败。
 FAILEDOPERATION_SNAPSHOTOPERATIONFAILED = 'FailedOperation.SnapshotOperationFailed'
 
-# 调用计费网关服务失败，请稍后重新操作操作。
+# TAT命令未完成。
+FAILEDOPERATION_TATINVOCATIONNOTFINISHED = 'FailedOperation.TATInvocationNotFinished'
+
+# 调用计费网关服务失败，请稍后重新操作。
 FAILEDOPERATION_TRADECALLBILLINGGATEWAYFAILED = 'FailedOperation.TradeCallBillingGatewayFailed'
 
 # 计费询价失败。
@@ -134,7 +161,7 @@ INTERNALERROR_INVALIDACTIONNOTFOUND = 'InternalError.InvalidActionNotFound'
 # 套餐价格错误。
 INTERNALERROR_INVALIDBUNDLEPRICE = 'InternalError.InvalidBundlePrice'
 
-# 命令 `DescribeInstanceLoginKeyPair` 无法找到。
+# 命令无法找到。
 INTERNALERROR_INVALIDCOMMANDNOTFOUND = 'InternalError.InvalidCommandNotFound'
 
 # 请求出现错误。
@@ -179,6 +206,9 @@ INVALIDPARAMETER_INVALIDFILTERINVALIDNAMENOTSTR = 'InvalidParameter.InvalidFilte
 # 参数非法，Filter 参数中的 Values 不是列表。
 INVALIDPARAMETER_INVALIDFILTERINVALIDVALUESNOTLIST = 'InvalidParameter.InvalidFilterInvalidValuesNotList'
 
+# Filter参数名称不正确。
+INVALIDPARAMETER_INVALIDFILTERNAME = 'InvalidParameter.InvalidFilterName'
+
 # 参数非法，Filter 参数不是字典。
 INVALIDPARAMETER_INVALIDFILTERNOTDICT = 'InvalidParameter.InvalidFilterNotDict'
 
@@ -197,6 +227,15 @@ INVALIDPARAMETER_PARAMETERCONFLICT = 'InvalidParameter.ParameterConflict'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 镜像不允许共享至不同站点的账号。
+INVALIDPARAMETERVALUE_ACCOUNTIDINVALIDACCOUNTAREA = 'InvalidParameterValue.AccountIdInvalidAccountArea'
+
+# 账号ID不存在。
+INVALIDPARAMETERVALUE_ACCOUNTIDSNOTEXIST = 'InvalidParameterValue.AccountIdsNotExist'
+
+# 账号ID不为主账号。
+INVALIDPARAMETERVALUE_ACCOUNTIDSNOTOWNERACCOUNT = 'InvalidParameterValue.AccountIdsNotOwnerAccount'
+
 # 该实例配置不符合指定镜像的要求。
 INVALIDPARAMETERVALUE_BLUEPRINTCONFIGNOTMATCH = 'InvalidParameterValue.BlueprintConfigNotMatch'
 
@@ -209,6 +248,9 @@ INVALIDPARAMETERVALUE_BLUEPRINTIDMALFORMED = 'InvalidParameterValue.BlueprintIdM
 # 套餐和镜像不匹配。
 INVALIDPARAMETERVALUE_BUNDLEANDBLUEPRINTNOTMATCH = 'InvalidParameterValue.BundleAndBlueprintNotMatch'
 
+# 所选套餐不支持镜像的操作系统平台类型。
+INVALIDPARAMETERVALUE_BUNDLENOTSUPPORTBLUEPRINTPLATFORM = 'InvalidParameterValue.BundleNotSupportBlueprintPlatform'
+
 # 云联网实例ID格式非法。
 INVALIDPARAMETERVALUE_CCNIDMALFORMED = 'InvalidParameterValue.CcnIdMalformed'
 
@@ -221,6 +263,9 @@ INVALIDPARAMETERVALUE_DISKBACKUPIDMALFORMED = 'InvalidParameterValue.DiskBackupI
 # 指定的云盘备份点名称不可大于最大长度。
 INVALIDPARAMETERVALUE_DISKBACKUPNAMETOOLONG = 'InvalidParameterValue.DiskBackupNameTooLong'
 
+# 云硬盘备份点配额小于当前云硬盘备份点数量。
+INVALIDPARAMETERVALUE_DISKBACKUPQUOTALESSTHENCURRENTDISKBACKUPNUM = 'InvalidParameterValue.DiskBackupQuotaLessThenCurrentDiskBackupNum'
+
 # 云硬盘的可用区与实例的可用区不匹配。
 INVALIDPARAMETERVALUE_DISKINSTANCEZONENOTMATCH = 'InvalidParameterValue.DiskInstanceZoneNotMatch'
 
@@ -230,12 +275,21 @@ INVALIDPARAMETERVALUE_DISKNAMETOOLONG = 'InvalidParameterValue.DiskNameTooLong'
 # 磁盘大小发生改变。
 INVALIDPARAMETERVALUE_DISKSIZENOTMATCH = 'InvalidParameterValue.DiskSizeNotMatch'
 
+# 指定云硬盘大小小于当前云硬盘大小。
+INVALIDPARAMETERVALUE_DISKSIZESMALLERTHANCURRENTDISKSIZE = 'InvalidParameterValue.DiskSizeSmallerThanCurrentDiskSize'
+
 # 参数 `KeyName` 已经存在且重复。
 INVALIDPARAMETERVALUE_DUPLICATEPARAMETERVALUE = 'InvalidParameterValue.DuplicateParameterValue'
 
 # 参数值非法，不允许包含重复的值。
 INVALIDPARAMETERVALUE_DUPLICATED = 'InvalidParameterValue.Duplicated'
 
+# 防火墙模板规则已存在
+INVALIDPARAMETERVALUE_DUPLICATEDFIREWALLTEMPLATERULE = 'InvalidParameterValue.DuplicatedFirewallTemplateRule'
+
+# 列值不正确。
+INVALIDPARAMETERVALUE_FIELDSCOMPARE = 'InvalidParameterValue.FieldsCompare'
+
 # 防火墙规则描述长度超出限制。
 INVALIDPARAMETERVALUE_FIREWALLRULEDESCRIPTIONTOOLONG = 'InvalidParameterValue.FirewallRuleDescriptionTooLong'
 
@@ -269,6 +323,9 @@ INVALIDPARAMETERVALUE_INVALIDCURINSTANCEDEADLINE = 'InvalidParameterValue.Invali
 # 参数值非法，磁盘 ID 格式非法。
 INVALIDPARAMETERVALUE_INVALIDDISKIDMALFORMED = 'InvalidParameterValue.InvalidDiskIdMalformed'
 
+# 指定云硬盘大小不符合要求。
+INVALIDPARAMETERVALUE_INVALIDDISKSIZE = 'InvalidParameterValue.InvalidDiskSize'
+
 # 云硬盘类型非法。
 INVALIDPARAMETERVALUE_INVALIDDISKTYPE = 'InvalidParameterValue.InvalidDiskType'
 
@@ -347,9 +404,15 @@ INVALIDPARAMETERVALUE_SNAPSHOTIDMALFORMED = 'InvalidParameterValue.SnapshotIdMal
 # 参数值非法，快照名称超过允许的最大长度。
 INVALIDPARAMETERVALUE_SNAPSHOTNAMETOOLONG = 'InvalidParameterValue.SnapshotNameTooLong'
 
+# 参数值非法，大于有效值。
+INVALIDPARAMETERVALUE_TOOLARGE = 'InvalidParameterValue.TooLarge'
+
 # 参数取值过长，超过最大长度。
 INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'
 
+# 参数值非法，小于有效值。
+INVALIDPARAMETERVALUE_TOOSMALL = 'InvalidParameterValue.TooSmall'
+
 # 非法的可用区。
 INVALIDPARAMETERVALUE_ZONEINVALID = 'InvalidParameterValue.ZoneInvalid'
 
@@ -371,6 +434,9 @@ LIMITEXCEEDED_DISKQUOTALIMITEXCEEDED = 'LimitExceeded.DiskQuotaLimitExceeded'
 # 超过防火墙规则配额。
 LIMITEXCEEDED_FIREWALLRULESLIMITEXCEEDED = 'LimitExceeded.FirewallRulesLimitExceeded'
 
+# 防火墙模板规则超出配额
+LIMITEXCEEDED_FIREWALLTEMPLATERULEQUOTALIMITEXCEEDED = 'LimitExceeded.FirewallTemplateRuleQuotaLimitExceeded'
+
 # 超过实例配额。
 LIMITEXCEEDED_INSTANCEQUOTALIMITEXCEEDED = 'LimitExceeded.InstanceQuotaLimitExceeded'
 
@@ -380,6 +446,9 @@ LIMITEXCEEDED_ISOLATERESOURCESLIMITEXCEEDED = 'LimitExceeded.IsolateResourcesLim
 # 超过密钥对配额。
 LIMITEXCEEDED_KEYPAIRLIMITEXCEEDED = 'LimitExceeded.KeyPairLimitExceeded'
 
+# 镜像当前配额不足，无法共享至指定账号。
+LIMITEXCEEDED_SHAREBLUEPRINTACROSSACCOUNTQUOTALIMITEXCEEDED = 'LimitExceeded.ShareBlueprintAcrossAccountQuotaLimitExceeded'
+
 # 超过快照配额。
 LIMITEXCEEDED_SNAPSHOTQUOTALIMITEXCEEDED = 'LimitExceeded.SnapshotQuotaLimitExceeded'
 
@@ -389,6 +458,9 @@ MISSINGPARAMETER = 'MissingParameter'
 # 必须传入参数Period或CurInstanceDeadline。
 MISSINGPARAMETER_MISSINGPARAMETERPERIODCURINSTANCEDEADLINE = 'MissingParameter.MissingParameterPeriodCurInstanceDeadline'
 
+# 镜像在操作中。请稍后再试。
+OPERATIONDENIED_BLUEPRINTOPERATIONINPROGRESS = 'OperationDenied.BlueprintOperationInProgress'
+
 # 该实例不支持升级套餐操作。
 OPERATIONDENIED_BUNDLENOTSUPPORTMODIFY = 'OperationDenied.BundleNotSupportModify'
 
@@ -422,6 +494,9 @@ OPERATIONDENIED_OPERATIONDENIEDCREATESNAPSHOT = 'OperationDenied.OperationDenied
 # 使用存储型套餐的实例不支持创建快照。
 OPERATIONDENIED_OPERATIONDENIEDCREATESNAPSHOTFORSTORAGEBUNDLE = 'OperationDenied.OperationDeniedCreateSnapshotForStorageBundle'
 
+# 镜像正在修改共享属性操作中。不支持此操作。
+RESOURCEINUSE_BLUEPRINTMODIFYINGSHAREPERMISSION = 'ResourceInUse.BlueprintModifyingSharePermission'
+
 # 磁盘备份点正在使用中，不支持此操作。
 RESOURCEINUSE_DISKBACKUPINUSE = 'ResourceInUse.DiskBackupInUse'
 
@@ -464,6 +539,12 @@ RESOURCENOTFOUND_FIREWALLNOTFOUND = 'ResourceNotFound.FirewallNotFound'
 # 防火墙规则不存在。
 RESOURCENOTFOUND_FIREWALLRULESNOTFOUND = 'ResourceNotFound.FirewallRulesNotFound'
 
+# 防火墙模板不存在
+RESOURCENOTFOUND_FIREWALLTEMPLATENOTFOUND = 'ResourceNotFound.FirewallTemplateNotFound'
+
+# 防火墙模板规则不存在
+RESOURCENOTFOUND_FIREWALLTEMPLATERULENOTFOUND = 'ResourceNotFound.FirewallTemplateRuleNotFound'
+
 # 实例不存在挂载的数据盘。
 RESOURCENOTFOUND_INSTANCEDATADISKNOTFOUND = 'ResourceNotFound.InstanceDataDiskNotFound'
 
@@ -476,6 +557,9 @@ RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'
 # 密钥对 ID 不存在。
 RESOURCENOTFOUND_KEYIDNOTFOUND = 'ResourceNotFound.KeyIdNotFound'
 
+# 密钥对不存在。
+RESOURCENOTFOUND_KEYPAIRNOTFOUND = 'ResourceNotFound.KeyPairNotFound'
+
 # 自定义镜像不存在。
 RESOURCENOTFOUND_PRIVATEBLUEPRINTNOTFOUND = 'ResourceNotFound.PrivateBlueprintNotFound'
 
@@ -494,18 +578,45 @@ RESOURCENOTFOUND_SNAPSHOTNOTFOUND = 'ResourceNotFound.SnapshotNotFound'
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# 指定实例镜像不符合要求。
+RESOURCEUNAVAILABLE_BLUEPRINTINVALID = 'ResourceUnavailable.BlueprintInvalid'
+
 # 镜像资源不可用。
 RESOURCEUNAVAILABLE_BLUEPRINTUNAVAILABLE = 'ResourceUnavailable.BlueprintUnavailable'
 
 # 套餐不可用。
 RESOURCEUNAVAILABLE_BUNDLEUNAVAILABLE = 'ResourceUnavailable.BundleUnavailable'
 
+# 不能应用该防火墙模板
+RESOURCEUNAVAILABLE_CANNOTAPPLYEMPTYFIREWALLTEMPLATE = 'ResourceUnavailable.CannotApplyEmptyFirewallTemplate'
+
+# Docker资源不可用。
+RESOURCEUNAVAILABLE_DOCKERUNAVAILABLE = 'ResourceUnavailable.DockerUnavailable'
+
+# 防火墙模板在使用中，不支持该操作。
+RESOURCEUNAVAILABLE_FIREWALLTEMPLATEINUSE = 'ResourceUnavailable.FirewallTemplateInUse'
+
+# TAT agent不可用。
+RESOURCEUNAVAILABLE_TATAGENTUNAVAILABLE = 'ResourceUnavailable.TATAgentUnavailable'
+
+# TAT 服务错误。
+RESOURCEUNAVAILABLE_TATSERVICEERROR = 'ResourceUnavailable.TATServiceError'
+
+# 套餐已售罄。
+RESOURCESSOLDOUT_BUNDLESOLDOUT = 'ResourcesSoldOut.BundleSoldOut'
+
 # 套餐无可用配置。
 RESOURCESSOLDOUT_PURCHASESOURCEHASNOBUNDLECONFIGS = 'ResourcesSoldOut.PurchaseSourceHasNoBundleConfigs'
 
 # 套餐无可用配置。
 RESOURCESSOLDOUT_ZONESHASNOBUNDLECONFIGS = 'ResourcesSoldOut.ZonesHasNoBundleConfigs'
 
+# 未授权操作。
+UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
+
+# 无效 Token。
+UNAUTHORIZEDOPERATION_INVALIDTOKEN = 'UnauthorizedOperation.InvalidToken'
+
 # MFA 已过期。
 UNAUTHORIZEDOPERATION_MFAEXPIRED = 'UnauthorizedOperation.MFAExpired'
 
@@ -515,6 +626,9 @@ UNAUTHORIZEDOPERATION_MFANOTFOUND = 'UnauthorizedOperation.MFANotFound'
 # 无权限。
 UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'
 
+# 无权限进行此操作，请求中token不合法。
+UNAUTHORIZEDOPERATION_TOKENINVALID = 'UnauthorizedOperation.TokenInvalid'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
@@ -530,9 +644,18 @@ UNSUPPORTEDOPERATION_ATTACHCCNCONDITIONUNSATISFIED = 'UnsupportedOperation.Attac
 # 关联云联网失败。请检查云联网状态并稍后再试。
 UNSUPPORTEDOPERATION_ATTACHCCNFAILED = 'UnsupportedOperation.AttachCcnFailed'
 
+# 镜像已经被共享。不支持此操作。
+UNSUPPORTEDOPERATION_BLUEPRINTALREADYSHARED = 'UnsupportedOperation.BlueprintAlreadyShared'
+
 # 镜像当前状态不支持该操作。
 UNSUPPORTEDOPERATION_BLUEPRINTCURSTATEINVALID = 'UnsupportedOperation.BlueprintCurStateInvalid'
 
+# 镜像没有被共享。不支持此操作。
+UNSUPPORTEDOPERATION_BLUEPRINTHASNOTSHARED = 'UnsupportedOperation.BlueprintHasNotShared'
+
+# 镜像最近一次的操作尚未完成。
+UNSUPPORTEDOPERATION_BLUEPRINTLATESTOPERATIONUNFINISHED = 'UnsupportedOperation.BlueprintLatestOperationUnfinished'
+
 # 镜像被使用中，不支持该操作。
 UNSUPPORTEDOPERATION_BLUEPRINTOCCUPIED = 'UnsupportedOperation.BlueprintOccupied'
 
@@ -596,6 +719,12 @@ UNSUPPORTEDOPERATION_LATESTOPERATIONUNFINISHED = 'UnsupportedOperation.LatestOpe
 # 共享镜像不支持此操作。
 UNSUPPORTEDOPERATION_NOTSUPPORTSHAREDBLUEPRINT = 'UnsupportedOperation.NotSupportSharedBlueprint'
 
+# 国际站不支持该操作。
+UNSUPPORTEDOPERATION_OPERATIONNOTSUPPORTEDININTLSITE = 'UnsupportedOperation.OperationNotSupportedInIntlSite'
+
+# 此接口已下线。
+UNSUPPORTEDOPERATION_OPERATIONOFFLINE = 'UnsupportedOperation.OperationOffline'
+
 # 计费资源中心删除资源失败。
 UNSUPPORTEDOPERATION_POSTDESTROYRESOURCEFAILED = 'UnsupportedOperation.PostDestroyResourceFailed'
 
@@ -605,6 +734,9 @@ UNSUPPORTEDOPERATION_RESETATTACHCCNFAILED = 'UnsupportedOperation.ResetAttachCcn
 # 资源不支持退换。
 UNSUPPORTEDOPERATION_RESOURCENOTRETURNABLE = 'UnsupportedOperation.ResourceNotReturnable'
 
+# 资源变配操作中新旧配置一样，不支持此操作。
+UNSUPPORTEDOPERATION_SAMEWITHOLDCONFIG = 'UnsupportedOperation.SameWithOldConfig'
+
 # 快照忙。
 UNSUPPORTEDOPERATION_SNAPSHOTBUSY = 'UnsupportedOperation.SnapshotBusy'
 
